@@ -1,3 +1,4 @@
+import re
 from json import loads as json_loads
 from pathlib import Path
 from typing import Any, Dict, Optional, Union
@@ -25,8 +26,13 @@ class BaiDu(HandOver):
             )
         else:
             raise ValueError("url or file is required")
-        resp_text, resp_url, _ = await self.post(
+        resp_text, _, _ = await self.post(
             "https://graph.baidu.com/upload", params=params, data=data
         )
-        resp_text, resp_url, _ = await self.get((json_loads(resp_text))["data"]["url"])
-        return BaiDuResponse(resp_text, resp_url)
+        next_url = (json_loads(resp_text))["data"]["url"]
+        resp_text, resp_url, _ = await self.get(next_url)
+        next_url = (re.search(r'"firstUrl":"([^"]+)"', resp_text)[1]).replace(r"\/", "/")  # type: ignore
+        resp_text, _, _ = await self.get(next_url)
+        next_url = (json_loads(resp_text))["data"]["ajaxTextUrl"]
+        resp_text, _, _ = await self.get(next_url)
+        return BaiDuResponse(json_loads(resp_text), resp_url)
